clj-kafka-x.consumers.shared

Clojure interface for Kafka Share Consumer API (KIP-932). Enables multiple consumers to read from the same partition, solving the Head of Line Blocking problem. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/KafkaShareConsumer.html

Clojure interface for Kafka Share Consumer API (KIP-932).
Enables multiple consumers to read from the same partition,
solving the Head of Line Blocking problem.
For complete JavaDocs, see:
https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/KafkaShareConsumer.html
raw docstring

clj-kafka-x.consumers.simple

Clojure interface for Kafka Consumer API. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/package-summary.html

Clojure interface for Kafka Consumer API.
For complete JavaDocs, see:
https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/package-summary.html
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries