Clojure interface for Kafka Share Consumer API (KIP-932). Enables multiple consumers to read from the same partition, solving the Head of Line Blocking problem. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/KafkaShareConsumer.html
Clojure interface for Kafka Share Consumer API (KIP-932). Enables multiple consumers to read from the same partition, solving the Head of Line Blocking problem. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/KafkaShareConsumer.html
Clojure interface for Kafka Consumer API. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/package-summary.html
Clojure interface for Kafka Consumer API. For complete JavaDocs, see: https://kafka.apache.org/42/javadoc/org/apache/kafka/clients/consumer/package-summary.html
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |